@@ -145,6 +145,18 @@ class Deserialize:
         except (decimal.InvalidOperation, TypeError, ValueError):
             return None
 
+    @classmethod
+    def string(cls, val: Any) -> Optional[str]:
+        """Return a value as a string. This method does no HTML escaping, so it should
+        only be used when HTML escaping is not a concern.
+        """
+        if val is None:
+            return None
+        sval = str(val).strip()
+        if not sval:
+            return None
+        return sval
+
     @classmethod
     def _text(
         cls, tags: HtmlTags, attributes: HtmlAttributes, val: Optional[str]
