@@ -20,6 +20,10 @@ class PolicyResult:
             return {}
         return self._messages.messages
 
+    def union(self, other: "PolicyResult") -> "PolicyResult":
+        messages = Messages().merge(self.messages).merge(other.messages)
+        return PolicyResult(self.is_valid and other.is_valid, messages)
+
     @classmethod
     def success(cls) -> "PolicyResult":
         return PolicyResult(True, None)
